@@ -89,7 +89,7 @@ def test_obj(base_url, browser, browser_version, os_version, os_name, remote_fla
         # extra.append(extras.image(gif_file, mime_type='image/gif', extension='gif'))
         #
         # test_obj.flush()
-        # test_obj.log_obj.remove_logger()  # Remove original log handlers
+        test_obj.log_obj.remove_logger()  # Remove original log handlers
         test_obj.wait(3)
         test_obj.teardown()
 
