@@ -4,7 +4,6 @@ Class to hold miscellaneous but useful decorators for our framework
 
 from inspect import getfullargspec
 import traceback
-
 import pytest_html
 
 
@@ -43,17 +42,19 @@ class Wrapit():
 
             # Run function with _screenshot decorator, get the return result (Expect boolean)
             result = func(*args, **kwargs)
+
             # If return True, only take screenshot if option -screenshot all
             # If return False, take screenshot for both -screenshot all/failonly
             # If not return boolean, skip screenshot
-            if args[0].screenshot == 'all':
-                screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
-                args[0].screenshot_counter += 1
-                args[0].save_screenshot(screenshot_name)
-            elif args[0].screenshot == 'failonly' and result is False:
-                screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
-                args[0].screenshot_counter += 1
-                args[0].save_screenshot(screenshot_name)
+            if not args[0].check_alert():              # Skip screenshot when there is an alert, otherwise will throw UnexpectedAlertPresentException
+                if args[0].screenshot == 'all':
+                    screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
+                    args[0].screenshot_counter += 1
+                    args[0].save_screenshot(screenshot_name)
+                elif args[0].screenshot == 'failonly' and result is False:
+                    screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
+                    args[0].screenshot_counter += 1
+                    args[0].save_screenshot(screenshot_name)
             return result
 
         return wrapper
@@ -68,10 +69,11 @@ class Wrapit():
                 print("Exception when trying to run test: %s" % __file__)
                 print("Python says:%s" % str(e))
                 test_obj.write(traceback.format_exc())
-                if test_obj.screenshot != 'off':        # Add for handling fail screenshot *Break case (Take screenshot for non off case)
-                    screenshot_name = '%003d' % test_obj.screenshot_counter + '_' + func.__name__
-                    test_obj.screenshot_counter += 1
-                    test_obj.save_screenshot(screenshot_name)
+                if not test_obj.check_alert():              # Skip screenshot when there is an alert, otherwise will throw UnexpectedAlertPresentException
+                    if test_obj.screenshot != 'off':        # Add for handling fail screenshot *Break case (Take screenshot for non off case)
+                        screenshot_name = '%003d' % test_obj.screenshot_counter + '_' + func.__name__
+                        test_obj.screenshot_counter += 1
+                        test_obj.save_screenshot(screenshot_name)
 
                 # Detail print in last line
                 with open(test_obj.logs_parent_dir + "\\" + test_obj.log_name, "a") as logfile:
@@ -92,10 +94,11 @@ class Wrapit():
                 print("Exception when trying to run test: %s" % __file__)
                 print("Python says:%s" % str(e))
                 test_obj.write(traceback.format_exc())
-                if test_obj.screenshot != 'off':        # Add for handling fail screenshot *Break case (Take screenshot for non off case)
-                    screenshot_name = '%003d' % test_obj.screenshot_counter + '_' + func.__name__
-                    test_obj.screenshot_counter += 1
-                    test_obj.save_screenshot(screenshot_name)
+                if not test_obj.check_alert():  # Skip screenshot when there is an alert, otherwise will throw UnexpectedAlertPresentException
+                    if test_obj.screenshot != 'off':        # Add for handling fail screenshot *Break case (Take screenshot for non off case)
+                        screenshot_name = '%003d' % test_obj.screenshot_counter + '_' + func.__name__
+                        test_obj.screenshot_counter += 1
+                        test_obj.save_screenshot(screenshot_name)
 
                 # Detail print in last line
                 with open(test_obj.logs_parent_dir + "\\" + test_obj.log_name, "a") as logfile:
@@ -116,10 +119,11 @@ class Wrapit():
                 print("Exception when trying to run test: %s" % __file__)
                 print("Python says:%s" % str(e))
                 test_mobile_obj.write(traceback.format_exc())
-                if test_mobile_obj.screenshot != 'off':        # Add for handling fail screenshot *Break case (Take screenshot for non off case)
-                    screenshot_name = '%003d' % test_mobile_obj.screenshot_counter + '_' + func.__name__
-                    test_mobile_obj.screenshot_counter += 1
-                    test_mobile_obj.save_screenshot(screenshot_name)
+                if not test_mobile_obj.check_alert():  # Skip screenshot when there is an alert, otherwise will throw UnexpectedAlertPresentException
+                    if test_mobile_obj.screenshot != 'off':        # Add for handling fail screenshot *Break case (Take screenshot for non off case)
+                        screenshot_name = '%003d' % test_mobile_obj.screenshot_counter + '_' + func.__name__
+                        test_mobile_obj.screenshot_counter += 1
+                        test_mobile_obj.save_screenshot(screenshot_name)
 
                 # Detail print in last line
                 with open(test_mobile_obj.logs_parent_dir + "\\" + test_mobile_obj.log_name, "a") as logfile:
